Praxis Seizure: Palma de Mallorca Palma de Mallorca, Spain January 21st 2001 Rubén Vidaña Crypt (12 cards, min=17, max=42, avg=7.5) ----------------------------------------- 2x Arika 11 DOM FOR OBF PRE aus cel inner circle Ventrue:2 2x Sir Walter Nash 7 DOM FOR PRE prince Ventrue:1 1x Democritus 10 DOM PRE aus cel for justicar Ventrue:1 1x Queen Anne 10 DOM FOR PRE aus obf prince Ventrue:2 1x Wilhelm Waldburg 9 DOM FOR PRE aus cel prince Ventrue:2 1x Emerson Bridges 8 DOM FOR PRE pot prince Ventrue:1 1x Timothy Crowley 7 FOR PRE ani dom prince Ventrue:1 1x Violette Prentiss 4 PRE dom Ventrue:1 1x Gideon Fontaine 3 PRE Ventrue:1 1x Roland Loussarian 3 for pre Ventrue:1 Library (90 cards) Master (14) 2x Blood Doll 1x Direct Intervention 1x Elysium: The Arboretum 1x Elysium: The Palace of Versailles 2x Fortitude 1x Hostile Takeover 1x Minion Tap 1x Secure Haven 1x Sudden Reversal 1x Tomb of Rameses III 1x Uptown Hunting Ground 1x Ventrue Headquarters Action (9) 3x Embrace, The 6x Govern the Unaligned Political Action (18) 4x Banishment 4x Consanguineous Boon 1x Kindred Restructure 7x Kine Resources Contested 2x Parity Shift Action Modifier (15) 4x Awe 2x Daring the Dawn 5x Freak Drive 2x Kiss of Ra, The 2x Voter Captivation Reaction (20) 10x Deflection 3x Forced Awakening 7x Second Tradition: Domain Combat (14) 10x Majesty 4x Rolling with the Punches